
## c8ylp plugin

```
Usage: c8ylp plugin COMMAND [ARGS]...

  Run a custom plugin (installed under ~/.c8ylp/plugins/)

  Example 1:

      c8ylp plugin command device01 -- ssh -p \$PORT myuser@localhost

Options:
  -h, --help  Show this message and exit.

Commands:
  command  Start once-off proxy and execute a (local) script/command

```
